Enum bincode::serde::SerializeError
[−]
[src]
pub enum SerializeError {
IoError(IoError),
SizeLimit,
Custom(String),
}An error that can be produced during encoding.
Variants
IoError(IoError)An error originating from the underlying Writer.
SizeLimitAn object could not be encoded with the given size limit.
This error is returned before any bytes are written to the
output Writer.
Custom(String)A custom error message